<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package CGB
 */

// Exit if accessed directly.
if (! defined('ABSPATH')) {
    exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function vw_ibtana_cgb_block_assets(){ 
    // phpcs:ignore
    // Styles.
    require_once plugin_dir_path( __FILE__ ) . '../auth/auth.php';
    wp_enqueue_style(
        'vw_ibtana-cgb-style-css', // Handle.
        plugins_url('dist/blocks.style.build.css', dirname(__FILE__)), // Block style CSS.
        array( 'wp-editor' ) // Dependency to include the CSS after it.
    );
}
// Hook: Frontend assets.
add_action('enqueue_block_assets', 'vw_ibtana_cgb_block_assets');

/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function vw_ibtana_cgb_editor_assets(){ 
    // phpcs:ignore
    // Scripts.
    wp_enqueue_script(
        'vw_ibtana-cgb-block-js', // Handle.
        plugins_url('/dist/blocks.build.js', dirname(__FILE__)), // Block.build.js: We register the block here. Built with Webpack.
        array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
        true // Enqueue the script in the footer.
    );
    wp_enqueue_script(
        'vw_ibtana-owl-js', // Handle.
        plugins_url('/dist/owl.carousel.js', dirname(__FILE__)), // Block.build.js: We register the block here. Built with Webpack.
        array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
        false // Enqueue the script in the footer.
    );
    wp_enqueue_script(
        'vw_ibtana-admin-script', // Handle.
        plugins_url('/dist/adminScript.js', dirname(__FILE__)), // Block.build.js: We register the block here. Built with Webpack.
        array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
        true // Enqueue the script in the footer.
    );
    wp_enqueue_style(
        'vw_ibtana-owl-css', // Handle.
        plugins_url('dist/assets/owl.carousel.css', dirname(__FILE__)), // Block editor CSS.
        array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
    );
    // Styles.
    wp_enqueue_style(
        'vw_ibtana-cgb-block-editor-css', // Handle.
        plugins_url('dist/blocks.editor.build.css', dirname(__FILE__)), // Block editor CSS.
        array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
        // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
    );
}

function vw_ibtana_editor_assets(){
    // Scripts.
    wp_enqueue_script('vw-ibtana-js', KT_BLOCKS_URL . 'dist/blocks.build.js', array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), KT_BLOCKS_VERSION, true);
    $editor_widths = get_option('vw_ibtana_editor_width', array());
    $sidebar_size = 750;
    $nosidebar_size = 1140;
    $jssize = 2000;
    if (! isset($editor_widths['enable_editor_width']) || 'true' === $editor_widths['enable_editor_width']) {
        if (isset($editor_widths['limited_margins']) && 'true' === $editor_widths['limited_margins']) {
            $add_size = 10;
        } else {
            $add_size = 30;
        }
        $post_type = get_post_type();
        if (isset($editor_widths['page_default']) && ! empty($editor_widths['page_default']) && isset($editor_widths['post_default']) && ! empty($editor_widths['post_default'])) {
            if (isset($post_type) && 'page' === $post_type) {
                $defualt_size_type = $editor_widths['page_default'];
            } else {
                $defualt_size_type = $editor_widths['post_default'];
            }
        } else {
            $defualt_size_type = 'sidebar';
        }
        if (isset($editor_widths['sidebar']) && ! empty($editor_widths['sidebar'])) {
            $sidebar_size = $editor_widths['sidebar'] + $add_size;
        } else {
            $sidebar_size = 750;
        }
        if (isset($editor_widths['nosidebar']) && ! empty($editor_widths['nosidebar'])) {
            $nosidebar_size = $editor_widths['nosidebar'] + $add_size;
        } else {
            $nosidebar_size = 1140 + $add_size;
        }
        if ('sidebar' == $defualt_size_type) {
            $default_size = $sidebar_size;
        } elseif ('fullwidth' == $defualt_size_type) {
            $default_size = 'none';
        } else {
            $default_size = $nosidebar_size;
        }
        if ('none' === $default_size) {
            $jssize = 2000;
        } else {
            $jssize = $default_size;
        }
    }
    wp_localize_script(
        'vw-ibtana-js',
        'vw_blocks_params',
        array(
            'sidebar_size' => $sidebar_size,
            'nosidebar_size' => $nosidebar_size,
            'default_size' => $jssize,
            'config'   => get_option('vw_ibtana_config_blocks'),
            'settings' => get_option('vw_ibtana_settings_blocks'),
        )
    );
    // Styles.
    wp_enqueue_style('vw-ibtana-editor-css', KT_BLOCKS_URL . 'dist/blocks.editor.build.css', array( 'wp-edit-blocks' ), KT_BLOCKS_VERSION);
    // Limited Margins.
    $editor_widths = get_option('vw_ibtana_editor_width', array());
    if (isset($editor_widths['limited_margins']) && 'true' === $editor_widths['limited_margins']) {
        wp_enqueue_style('vw-ibtana-limited-margins-css', KT_BLOCKS_URL . 'dist/limited-margins.css', array( 'wp-edit-blocks' ), KT_BLOCKS_VERSION);
    }
}
add_action('enqueue_block_editor_assets', 'vw_ibtana_editor_assets');

/**
 * Register Meta for blocks width
 */
function vw_ibtana_init_post_meta(){
    register_post_meta(
        '',
        'vw_ibtana_editor_width',
        array(
            'show_in_rest' => true,
            'single' => true,
            'type' => 'string',
        )
    );
}
add_action('init', 'vw_ibtana_init_post_meta');

/**
 * Add inline css editor width
 */
function vw_ibtana_admin_editor_width(){
    $editor_widths = get_option('vw_ibtana_editor_width', array());
    if (! isset($editor_widths['enable_editor_width']) || 'true' === $editor_widths['enable_editor_width']) {
        if (isset($editor_widths['limited_margins']) && 'true' === $editor_widths['limited_margins']) {
            $add_size = 10;
        } else {
            $add_size = 30;
        }
        $post_type = get_post_type();
        if (isset($editor_widths['page_default']) && ! empty($editor_widths['page_default']) && isset($editor_widths['post_default']) && ! empty($editor_widths['post_default'])) {
            if (isset($post_type) && 'page' === $post_type) {
                $defualt_size_type = $editor_widths['page_default'];
            } else {
                $defualt_size_type = $editor_widths['post_default'];
            }
        } else {
            $defualt_size_type = 'sidebar';
        }
        if (isset($editor_widths['sidebar']) && ! empty($editor_widths['sidebar'])) {
            $sidebar_size = $editor_widths['sidebar'] + $add_size;
        } else {
            $sidebar_size = 750;
        }
        if (isset($editor_widths['nosidebar']) && ! empty($editor_widths['nosidebar'])) {
            $nosidebar_size = $editor_widths['nosidebar'] + $add_size;
        } else {
            $nosidebar_size = 1140 + $add_size;
        }
        if ('sidebar' == $defualt_size_type) {
            $default_size = $sidebar_size;
        } elseif ('fullwidth' == $defualt_size_type) {
            $default_size = 'none';
        } else {
            $default_size = $nosidebar_size;
        }
        if ('none' === $default_size) {
            $jssize = 2000;
        } else {
            $jssize = $default_size;
        }
        echo '<style type="text/css" id="vw-block-editor-width">';
        echo 'body.gutenberg-editor-page.vw-editor-width-default .editor-post-title__block,
        body.gutenberg-editor-page.vw-editor-width-default .editor-default-block-appender,
        body.gutenberg-editor-page.vw-editor-width-default .editor-block-list__block,
        body.block-editor-page.vw-editor-width-default .wp-block {
            max-width: ' . esc_attr($default_size) . (is_numeric($default_size) ? 'px' : '') . ';
        }';
        echo 'body.gutenberg-editor-page.vw-editor-width-sidebar .editor-post-title__block,
        body.gutenberg-editor-page.vw-editor-width-sidebar .editor-default-block-appender,
        body.gutenberg-editor-page.vw-editor-width-sidebar .editor-block-list__block,
        body.block-editor-page.vw-editor-width-sidebar .wp-block {
            max-width: ' . esc_attr($sidebar_size) . 'px;
        }';
        echo 'body.gutenberg-editor-page.vw-editor-width-nosidebar .editor-post-title__block,
        body.gutenberg-editor-page.vw-editor-width-nosidebar .editor-default-block-appender,
        body.gutenberg-editor-page.vw-editor-width-nosidebar .editor-block-list__block,
        body.block-editor-page.vw-editor-width-nosidebar .wp-block {
            max-width: ' . esc_attr($nosidebar_size) . 'px;
        }';
        echo 'body.gutenberg-editor-page.vw-editor-width-fullwidth .editor-post-title__block,
        body.gutenberg-editor-page.vw-editor-width-fullwidth .editor-default-block-appender,
        body.gutenberg-editor-page.vw-editor-width-fullwidth .editor-block-list__block,
        body.block-editor-page.vw-editor-width-fullwidth .wp-block {
            max-width: none;
        }';
        echo 'body.gutenberg-editor-page .editor-block-list__layout .editor-block-list__block[data-align=wide],
        body.block-editor-page .editor-block-list__layout .wp-block[data-align=wide] {
            width: auto;
            max-width: ' . esc_attr($nosidebar_size + 200) . 'px;
        }';

        echo 'body.gutenberg-editor-page .editor-block-list__layout .editor-block-list__block[data-align=full],
        body.block-editor-page .editor-block-list__layout .wp-block[data-align=full] {
            max-width: none;
        }';
        echo '</style>';
        echo "<script> var vw_ibtana_sidebar_size = " . $sidebar_size . "; var vw_ibtana_nosidebar_size = " . $nosidebar_size . "; var vw_ibtana_default_size = " . $jssize . ";</script>";
    }
}
add_action('admin_head-post.php', 'vw_ibtana_admin_editor_width', 100);
add_action('admin_head-post-new.php', 'vw_ibtana_admin_editor_width', 100);

/**
 * Add class to match editor width.
 *
 * @param string $classes string of body classes.
 */
function vw_ibtana_admin_body_class($classes){
    $screen = get_current_screen();
    if ('post' == $screen->base) {
        global $post;
        $editorwidth = get_post_meta($post->ID, 'vw_ibtana_editor_width', true);
        if (isset($editorwidth) && ! empty($editorwidth) && 'default' !== $editorwidth) {
            $classes .= ' vw-editor-width-' . esc_attr($editorwidth);
        } else {
            $classes .= ' vw-editor-width-default';
        }
    }
    return $classes;
}

add_filter('admin_body_class', 'vw_ibtana_admin_body_class');
// Hook: Editor assets.
// Hook: Editor assets.
add_action('enqueue_block_editor_assets', 'vw_ibtana_cgb_editor_assets');
function register_frontend_script()
{
    wp_enqueue_script('owl', plugins_url('/dist/owl.carousel.js', dirname(__FILE__)), array( 'jquery'), '1.0', true);
    wp_enqueue_script('scripts', plugins_url('/dist/scripts.js', dirname(__FILE__)), array( 'jquery'), '1.0', true);
}
add_action('wp_enqueue_scripts', 'register_frontend_script');

function vw_ibtana_pro_setup() {
add_theme_support( 'align-wide' );
}
add_action( 'after_setup_theme', 'vw_ibtana_pro_setup' );